# UI/UX Feedback

**ID:** Feedback-20260304-134328
**URL:** http://127.0.0.1:5858/
**Date:** 2026-03-04 13:46:10

## Selected Elements

- `{'selector': 'button.action-btn:nth-of-type(3)', 'parents': ['div.workflow-panel-body', 'div.actions-area', 'div.action-group', 'div.actions-grid']}`

## Feedback

let's change the behavior, during action execution, it would become unclickable, and no in progress animation, could you change the the logic a bit, let it still able to click no matter in execution or not, if in execution, add animation to the action indicate it's running, so you need persist the running state, if page refreshed, just show original status

## Screenshot

![Screenshot](x-ipe-docs/uiux-feedback/Feedback-20260304-134328/page-screenshot.png)
